@@ -1,8 +1,11 @@
 package Gapp::App;
+{
+  $Gapp::App::VERSION = '0.002'; # TRIAL
+}
 
 use Moose;
 
-our $VERSION = '0.01';
+use Gapp::App::Widget::Traits::HasApp;
 
 
 1;
@@ -40,10 +43,6 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
     
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
-    
-    Individual packages in this module may have have multiple copyrights and
-    licenses. Please refer to the documentation of indivdual packages for more
-    information. (see L<Gapp::Actions>, L<Gapp::TableMap>)
 
 =cut
 
